"use client"

import React from "react";
import {
	faFacebookF,
	faLinkedin,
	faTwitter,
	faYoutube,
	faInstagram
} from "@fortawesome/free-brands-svg-icons";

import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import Image from "next/image";
import Link from "next/link";
import { helpCenterAppUrl, rfwAppUrl, universityAppUrl } from "@/helpers/routes";


const allTracks = [
	{
		name: "UX UI",
		image: "/images/track-card-03.jpg",
		lessons: "Beginner friendly: 5 Lessons",
		link: universityAppUrl("/ux-ui"),

	},
	{
		name: "Data Science",
		image: "/images/track-card-04.jpg",
		lessons: "Beginner friendly: 8 Lessons",
		link: universityAppUrl("/data-science"),

	},
	{
		name: "Digital Marketing",
		image: "/images/track-card-02.jpg",
		lessons: "Beginner friendly: 5 Lessons",
		link: universityAppUrl("/digital-marketing"),

	},
	{
		name: "Financial Analysis",
		image: "/images/track-card-01.jpg",
		lessons: "Beginner friendy: 4 Lessons",
		link: universityAppUrl("/financial-analysis"),

	},

	{
		name: "Software Engineering",
		image: "/images/track-card-05.jpg",
		lessons: "Beginner friendly: 6 Lessons",
		link: universityAppUrl("/software-engineering"),

	},
];

const socialHandles = [
	{
		name: "Facebook",
		icon: faFacebookF,
		link: "https://facebook.com/myreadyforwork",
	},
	{
		name: "Twitter",
		icon: faTwitter,
		link: "https://twitter.com/myreadyforwork",
	},
	{
		name: "YouTube",
		icon: faYoutube,
		link: "https://youtube.com/c/starsfromallnations",
	},
	{
		name: "LinkedIn",
		icon: faLinkedin,
		link: "https://linkedin.com/company/sfan",
	},
	{
		name: "Instagram",
		icon: faInstagram,
		link: "https://www.instagram.com/sfanonline/"
	}
];

const Footer = (): JSX.Element => {

	return (
		<>
			<div className="bg-black text-white pt-1 px-4 lg:px-20 ">
				<div className="flex flex-col lg:flex-row justify-center md:justify-between mb-12">
					<div className=" w-full lg:w-6/12 my-5 flex flex-col items-start px-6 md:px-0">
						<div className="flex items-center">
							<Link href={rfwAppUrl()}>
								<Image
									width={256}
									height={150}
									className="w-40 lg:w-64"
									src="/images/rfw-footer-logo.png"
									alt="RFW Logo"
								/>
							</Link>
						</div>

						<div className="px-1">
							<p className="max-w-lg my-5 ">
								ReadyforWork is an immersive career accelerator that uses
								Artificial Intelligence and Machine Learning to help entry-level
								job seekers upskill and future-proof their careers with in-demand
								digital skills and give businesses access to diverse,
								less-expensive emerging talent pipeline.
							</p>

							<div className="mt-6 max-w-lg  ">
								<p className="mt-1">King Solomon&rsquo;s Heights</p>
								<p className="mt-1">26, Mango Street, Accra, Ghana</p>
								<p className="mt-1">(+233) 030 280 2935</p>
								<p className="mt-1">info@sfanonline.org</p>

								<div className="flex items-center justify-left sm:justify-start space-x-5 text-center mt-2">
									{socialHandles.map((handle) => (
										<div key={"handle-" + handle.name} title={handle.name}>
											<a href={handle.link} target="_blank">
												<FontAwesomeIcon
													className="w-4 hover:scale-150 transform duration-150 ease-in-out"
													icon={handle.icon}
												/>
											</a>
										</div>
									))}
								</div>
							</div>
						</div>
					</div>

					<div className="hidden relative  my-5 md:flex -mr-5 flex-col lg:w-6/12 items-start divide-y space-y-5 sm:space-y-0  sm:divide-y-0 sm:flex-row  sm:justify-around ">
						<div className=" w-full text-center sm:text-left sm:w-auto">
							<h3 className="font-black text-xs md:text-sm italic">Tracks</h3>

							<ul>
								{allTracks.map((track, idx: number) => {
									return (
										<li key={"handle-" + track.name} className="mt-1">
											<Link href={track.link} className="hover:text-rfw-summer">
												{track.name}
											</Link>
										</li>
									);
								})}
							</ul>
						</div>

						<div className="w-full  text-center sm:text-left sm:w-auto ">
							<div>
								<h3 className="font-black text-xs md:text-sm md:text-left italic">
									Help & Legal
								</h3>

								<ul className="md:text-left ">
									<li>
										<Link href={"/"} className="hover:text-rfw-summer">
											FAQs
										</Link>
									</li>
									<li>
										<a href={universityAppUrl("/auth/register")} className="hover:text-rfw-summer">
											Sign Up
										</a>
									</li>
									<li className="mt-1">
										<a href={universityAppUrl("/auth/login")} className="hover:text-rfw-summer">
											Login
										</a>
									</li>
									<li className="mt-1">
										<Link href="https://www.readyforwork.africa/privacy" className="hover:text-rfw-summer">
											Privacy
										</Link>
									</li>
									<li className="mt-1">
										<Link href="https://www.readyforwork.africa/terms" className="hover:text-rfw-summer">
											Terms of Use
										</Link>
									</li>
								</ul>
							</div>

							{/* <div className="mt-2">
								<h3 className="font-black text-xs md:text-sm md:text-left italic">
									User
								</h3>

								<ul className="md:text-left ">
									
								</ul>
							</div> */}
						</div>

						<div className="w-full text-center sm:text-left sm:w-auto ">
							<h3 className="font-black text-xs md:text-sm italic">Company</h3>

							<ul>
								<li className="mt-1">
									<a
										href="https://sfanonline.org/about"
										className="hover:text-rfw-summer"
									>
										About Us
									</a>
								</li>
								<li className="mt-1">
									<Link href={rfwAppUrl("/contact")} className="hover:text-rfw-summer">
										Contact Us
									</Link>
								</li>

								<li className="mt-1">
									<Link href={rfwAppUrl("/coaching")} className="hover:text-rfw-summer">
										Coaching
									</Link>
								</li>

								<li className="mt-1">
									<Link href={rfwAppUrl("/business")} className="hover:text-rfw-summer">
										For Business
									</Link>
								</li>

								<li className="mt-1">
									<Link href={universityAppUrl()} className="hover:text-rfw-summer">
										For Education
									</Link>
								</li>
							</ul>
						</div>

						<div className="w-full hidden lg:absolute lg:left-10 lg:bottom-10 text-white bg-transparent">
							<a
								href="https://starsfromallnations.substack.com/subscribe"
								className="rfw-btn rfw-btn-secondary-outline"
							>
								Subscribe to our newsletter
							</a>
						</div>
					</div>

					<div className=" grid grid-cols-2 gap-4  md:hidden   ">
						<div className="col-span-1 justify-self-center ">
							<h3 className="font-black text-xs md:text-sm italic">Tracks</h3>

							<ul>
								{allTracks.map((track, idx: number) => {
									return (
										<li className="mt-1" key={idx}>
											<Link href={track.link} className="hover:text-rfw-summer">
												{track.name}
											</Link>
										</li>
									);
								})}
							</ul>
						</div>

						<div className="col-span-1 justify-self-center ">
							<h3 className="font-black text-xs md:text-sm italic">Company</h3>

							<ul>
								<li className="mt-1">
									<a
										href="https://sfanonline.org/about"
										className="hover:text-rfw-summer"
									>
										About Us
									</a>
								</li>
								<li className="mt-1">
									<Link href={rfwAppUrl("/contact")} className="hover:text-rfw-summer">
										Contact Us
									</Link>
								</li>

								<li className="mt-1">
									<Link href={rfwAppUrl("/coaching")} className="hover:text-rfw-summer">
										Coaching
									</Link>
								</li>

								<li className="mt-1">
									<Link href={rfwAppUrl("/business")} className="hover:text-rfw-summer">
										For Business
									</Link>
								</li>

								<li className="mt-1">
									<Link href={universityAppUrl()} className="hover:text-rfw-summer">
										For Education
									</Link>
								</li>
							</ul>
						</div>

						<div className=" col-span-1 justify-self-center ">
							<div>
								<h3 className="font-black text-xs md:text-xl md:text-left">
									Help
								</h3>

								<ul className="md:text-left ">
									<li>
										<Link href={"/"} className="hover:text-rfw-summer">
											FAQs
										</Link>
									</li>
									<li className="mt-1">
										<Link href={rfwAppUrl("/privacy")}>Privacy</Link>
									</li>
									<li className="mt-1">
										<Link href={rfwAppUrl("/terms")}>Terms of use</Link>
									</li>
								</ul>
							</div>
						</div>

						<div className="col-span-1 justify-self-center ">
							<div>
								<h3 className="font-black text-xs md:text-xl md:text-left">
									User
								</h3>

								<ul className="md:text-left ">
									<li>
										<Link href={universityAppUrl("/auth/register")} className="hover:text-rfw-summer">
											Sign Up
										</Link>
									</li>
									<li className="mt-1">
										<Link href={universityAppUrl("/auth/register")} className="hover:text-rfw-summer">
											Login
										</Link>
									</li>
									<li className="mt-1 invisible">For Education</li>
								</ul>
							</div>
						</div>

						<div className="col-span-full text-center text-white bg-transparent"></div>
					</div>
				</div>

				<div className="text-center border-t border-gray-600 py-6 font-extralight ">
					<h4 className="text-[14px]">
						&copy; 2019 - {new Date().getFullYear()} <a className="text-rfw-summer" href="https://sfanonline.org">Stars From All Nations </a>
						| All Rights Reserved
					</h4>
				</div>
			</div>
		</>
	);
};


export default Footer;
